lanyard
Types
Values
pub fn custom_length(size: Int) -> NanoID
Generate a new NanoID using the default alphabet, but a custom length. The default alphabet is A-Z (capitals), a-z (lowercase), 0-9, and both - and _.
If a negative length is provided, this will return a blank ID.